@@ -1,5 +1,4 @@
-#include "torch_types.h"
-#include "utils.h" 
+#include <torch.h>
 
 // [[Rcpp::export]]
 std::string cpp_qscheme_to_string(Rcpp::XPtr<XPtrTorchQScheme> x) {
@@ -7,22 +6,21 @@ std::string cpp_qscheme_to_string(Rcpp::XPtr<XPtrTorchQScheme> x) {
 }
 
 // [[Rcpp::export]]
-Rcpp::XPtr<XPtrTorchQScheme> cpp_torch_per_channel_affine () {
+Rcpp::XPtr<XPtrTorchQScheme> cpp_torch_per_channel_affine() {
   return make_xptr<XPtrTorchQScheme>(lantern_QScheme_per_channel_affine());
 }
 
 // [[Rcpp::export]]
-Rcpp::XPtr<XPtrTorchQScheme> cpp_torch_per_tensor_affine () {
+Rcpp::XPtr<XPtrTorchQScheme> cpp_torch_per_tensor_affine() {
   return make_xptr<XPtrTorchQScheme>(lantern_QScheme_per_tensor_affine());
 }
 
 // [[Rcpp::export]]
-Rcpp::XPtr<XPtrTorchQScheme> cpp_torch_per_channel_symmetric () {
+Rcpp::XPtr<XPtrTorchQScheme> cpp_torch_per_channel_symmetric() {
   return make_xptr<XPtrTorchQScheme>(lantern_QScheme_per_channel_symmetric());
 }
 
 // [[Rcpp::export]]
-Rcpp::XPtr<XPtrTorchQScheme> cpp_torch_per_tensor_symmetric () {
+Rcpp::XPtr<XPtrTorchQScheme> cpp_torch_per_tensor_symmetric() {
   return make_xptr<XPtrTorchQScheme>(lantern_QScheme_per_tensor_symmetric());
 }
-
